﻿using System;
using System.Drawing;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();
            
            this.chart.Name   = "chart";
            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "상하한(High-Low) 차트";

            ViewXY viewXY = this.chart.ViewXY;

            AxisX axisX = viewXY.XAxes[0];

            axisX.Title.Font         = Font;
            axisX.Title.Text         = "연도";
            axisX.ValueType          = AxisValueType.Number;
            axisX.MajorDiv           = 1;
            axisX.AutoFormatLabels   = false;
            axisX.LabelsNumberFormat = "0";

            AxisY axisY = viewXY.YAxes[0];

            axisY.Title.Font = Font;
            axisY.Title.Text = "(백만원)";
            axisY.Minimum    = 0;

            ChartHelper.SetDarkFlatStyle(this.chart);

            HighLowSeries series = new HighLowSeries(viewXY, axisX, axisY);

            series.Title.Text               = "판매/비용";
            series.LineStyleHigh.Color      = Color.Gold;
            series.LineStyleLow.Color       = Color.Red;
            series.MouseInteraction         = false;
            series.Fill.Color               = Color.FromArgb(180, Color.Orange);
            series.Fill.GradientFill        = GradientFill.Solid;
            series.ReverseFill.Color        = Color.FromArgb(180, 255, 64, 0);
            series.ReverseFill.GradientFill = GradientFill.Solid;

            int pointCount = 200;

            Random random = new Random();

            HighLowSeriesPoint[] pointArray = new HighLowSeriesPoint[pointCount];

            for(int i = 0; i < pointCount; i++)
            {
                pointArray[i].X     = 2000 + (double)i / 12.0;
                pointArray[i].YHigh = 28 + (random.NextDouble() - 0.5) * 2 + (10.0 + (double)i / 20) * Math.Sin(100 - (double)i / 22.0);
                pointArray[i].YLow  = 25 + (random.NextDouble() - 0.5) * 1.5 + 2.0 * Math.Cos(98.8 + (double)i / 12.0);
            }

            series.Points = pointArray;

            viewXY.HighLowSeries.Add(series);

            viewXY.ZoomToFit();

            LegendBoxXY legendBoxXY = viewXY.LegendBoxes[0];

            legendBoxXY.Position = LegendBoxPositionXY.SegmentBottomRight;

            this.chart.EndUpdate();
        }

        #endregion
    }
}